aboutsummaryrefslogtreecommitdiffstats
path: root/packet-mmse.c
diff options
context:
space:
mode:
authorGuy Harris <guy@alum.mit.edu>2002-06-05 23:54:10 +0000
committerGuy Harris <guy@alum.mit.edu>2002-06-05 23:54:10 +0000
commitb9ba6ca17650a0b03c1da2d94640b40e67c118ad (patch)
treec769f463bdc156de1ec52eaef3b05c042d3192b7 /packet-mmse.c
parentd0773ba9bffe3206b12020e7a9a5cc61ae268980 (diff)
From Martin Gignac: make the MMS heuristic dissector recognize packets
that lack a Transaction-Id header, as some packets don't have one. svn path=/trunk/; revision=5630
Diffstat (limited to 'packet-mmse.c')
-rw-r--r--packet-mmse.c8
1 files changed, 5 insertions, 3 deletions
diff --git a/packet-mmse.c b/packet-mmse.c
index ec3e82b9a2..32aea542e3 100644
--- a/packet-mmse.c
+++ b/packet-mmse.c
@@ -2,7 +2,7 @@
* Routines for MMS Message Encapsulation dissection
* Copyright 2001, Tom Uijldert <tom.uijldert@cmg.nl>
*
- * $Id: packet-mmse.c,v 1.10 2002/06/05 19:03:42 guy Exp $
+ * $Id: packet-mmse.c,v 1.11 2002/06/05 23:54:10 guy Exp $
*
* Ethereal - Network traffic analyzer
* By Gerald Combs <gerald@ethereal.com>
@@ -332,14 +332,16 @@ dissect_mmse_heur(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
/*
* Check if data makes sense for it to be dissected as MMSE: Message-type
* field must make sense and followed by Transaction-Id header
*/
if (tvb_get_guint8(tvb, 0) != MM_MTYPE_HDR)
return FALSE;
pdut = tvb_get_guint8(tvb, 1);
if (match_strval(pdut, vals_message_type) == NULL)
return FALSE;
- if (tvb_get_guint8(tvb, 2) != MM_TID_HDR)
+ if ((tvb_get_guint8(tvb, 2) != MM_TID_HDR) &&
+ (tvb_get_guint8(tvb, 2) != MM_VERSION_HDR))
return FALSE;
dissect_mmse(tvb, pinfo, tree);
return TRUE;
@@ -332,14 +332,16 @@ dissect_mmse_heur(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
/*
* Check if data makes sense for it to be dissected as MMSE: Message-type
- * field must make sense and followed by Transaction-Id header
+ * field must make sense and followed by either Transaction-Id
+ * or MMS-Version header
*/
if (tvb_get_guint8(tvb, 0) != MM_MTYPE_HDR)